# bqslots


[![image](https://img.shields.io/pypi/v/bqslots.svg)](https://pypi.python.org/pypi/bqslots)

[![image](https://img.shields.io/conda/vn/conda-forge/bqslots.svg)](https://anaconda.org/conda-forge/bqslots)

[![image](https://pyup.io/repos/github/connor-ps/bqslots/shield.svg)](https://pyup.io/repos/github/connor-ps/bqslots)


**A small wrapper for bigquery slot allocaiton**


-   Free software: MIT license
-   Documentation: https://connor-ps.github.io/bqslots
    

## Features

-   Basic client to allocate slots to GCP project

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
